@@ -34,23 +34,38 @@ class Generator(object):
         self._scraped_scripts = []
         self._mixed_script = ''
 
+        def to_pattern(s: str) -> re.Pattern:
+            if s.startswith('^'):
+                return re.compile(s)
+            return re.compile(f'^{s}')
+
+        self._exclude_page_patterns = list(map(
+            to_pattern,
+            self._options.exclude_pages
+        ))
+        self._options.logger.debug(
+            f'Exclude page patterns: {self._exclude_page_patterns}')
+
     def on_nav(self, nav):
         """ on_nav """
         self._nav = nav
         if nav:
-            self._options.logger.debug('theme: %s', self._theme)
+            self._options.logger.debug(f'theme: {self._theme}')
 
     def on_post_page(self, output_content: str, page, pdf_path: str) -> str:
         """ on_post_page """
 
         def is_excluded(url: str) -> bool:
-            return url in self._options.exclude_pages
+            for p in self._exclude_page_patterns:
+                if p.match(url):
+                    return True
+            return False
 
         if is_excluded(page.url):
-            self.logger.info('Page skipped: [%s](%s)', page.title, page.url)
-            return "<!-- skipped '{}' -->".format(page)
+            self.logger.info(f'Page skipped: [{page.title}]({page.url})')
+            return f"<!-- skipped '{page}' -->"
         else:
-            self.logger.debug(' (post: [%s](%s)', page.title, page.url)
+            self.logger.debug(f' (post: [{page.title}]({page.url})')
 
         soup = self._soup_from_content(output_content, page)
 
@@ -58,7 +73,7 @@ class Generator(object):
 
         if not self._head:
             self._head = soup.find('head')
-            # self.logger.debug('%s', self._head)
+            # self.logger.debug(f'{self._head}')
 
         # for 'material'
         article = soup.find('article')
@@ -83,8 +98,7 @@ class Generator(object):
             setattr(page, 'pdf-article', article)
             self._scrap_scripts(soup)
         else:
-            self.logger.warning(
-                'Missing article: [%s](%s)', page.title, page.url)
+            self.logger.warning(f'Missing article: [{page.title}]({page.url})')
 
         return self._options.hook.inject_link(
             output_content, pdf_path, page, self._theme)
@@ -129,7 +143,7 @@ class Generator(object):
         html_string = self._options.hook.pre_pdf_render(html_string)
 
         if self._options.debug_html:
-            print(html_string)
+            print(f'{html_string}')
 
         self.logger.info("Rendering for PDF.")
         html = HTML(string=html_string)
@@ -138,7 +152,7 @@ class Generator(object):
         abs_pdf_path = os.path.join(config['site_dir'], output_path)
         os.makedirs(os.path.dirname(abs_pdf_path), exist_ok=True)
 
-        self.logger.info('Output a PDF to "%s".', abs_pdf_path)
+        self.logger.info(f'Output a PDF to "{abs_pdf_path}".')
         render.write_pdf(abs_pdf_path)
 
     # ------------------------
@@ -157,7 +171,7 @@ class Generator(object):
             hit = False
             for x in soup.find_all():
                 if x.name in includes and is_blank(x):
-                    # self.logger.debug('Strip: %s'%(x))
+                    # self.logger.debug(f'Strip: {x}')
                     x.extract()
                     hit = True
             if not hit:
@@ -200,18 +214,18 @@ class Generator(object):
         def shift_heading(elem, page):
             for i in range(7, 0, -1):
                 while True:
-                    h = elem.find('h%d' % (i))
+                    h = elem.find(f'h{i}')
                     if not h:
                         break
-                    h.name = 'h%d' % (i + 1)
+                    h.name = f'h{i + 1}'
 
             page_path = self._page_path_for_id(page)
-            h1 = soup.new_tag('h1', id=str(page_path))
+            h1 = soup.new_tag('h1', id=f'{page_path}')
             h1.append(page.title)
             elem.insert(0, h1)
             return elem
 
-        def cleanup_class(classes: []):
+        def cleanup_class(classes):
             if classes and len(classes):
                 excludes = ['md-content__inner']
                 return [c for c in classes if not (c in excludes)]
@@ -221,8 +235,8 @@ class Generator(object):
         if article:
 
             page_path = self._page_path_for_id(page)
-            article['id'] = '{}:'.format(page_path)  # anchor for each page.
-            article['data-url'] = '/{}'.format(page_path)
+            article['id'] = f'{page_path}:'  # anchor for each page.
+            article['data-url'] = f'/{page_path}'
             return article
 
         elif page.children:
@@ -247,9 +261,8 @@ class Generator(object):
                 child_article['class'] = cleanup_class(classes)
 
             page_path = self._page_path_for_id(page)
-            # anchor for each page.
-            new_article['id'] = '{}:'.format(page_path)
-            new_article['data-url'] = '/{}'.format(page_path)
+            new_article['id'] = f'{page_path}:'  # anchor for each page.
+            new_article['data-url'] = f'/{page_path}'
             if child_classes:
                 new_article['class'] = child_classes
 
@@ -284,15 +297,14 @@ class Generator(object):
                 return mod
             except FileNotFoundError as e:
                 self.logger.error(
-                    'Could not load theme handler %s'
-                    ' from custom directory "%s": %s',
-                    theme, custom_handler_path, e)
+                    f'Could not load theme handler {theme}'
+                    f' from custom directory "{custom_handler_path}": {e}')
                 pass
 
         try:
             return import_module(module_name, 'mkdocs_with_pdf.themes')
         except ImportError as e:
-            self.logger.error('Could not load theme handler %s: %s', theme, e)
+            self.logger.error(f'Could not load theme handler {theme}: {e}')
             return generic_theme
 
     # -------------------------------------------------------------
@@ -322,7 +334,7 @@ class Generator(object):
         if not (self._options.strict or self._options.debug_html):
             self.logger.info('Anchor points provided:')
             for anchor in sorted(anchors):
-                self.logger.info('| %s', anchor)
+                self.logger.info(f'| {anchor}')
             return
 
         missing = set()
@@ -338,15 +350,15 @@ class Generator(object):
             missing.add(href)
 
         if len(missing):
-            self.logger.error('Missing %d link(s):', len(missing))
+            self.logger.error(f'Missing {len(missing)} link(s):')
             for link in sorted(missing):
-                self.logger.warning('  | %s', link)
+                self.logger.warning(f'  | {link}')
             if (self._options.show_anchors or
                 self._options.verbose or
                     self._options.debug_html):
                 self.logger.info('  | --- found anchors:')
                 for anchor in sorted(anchors):
-                    self.logger.info('  | %s', anchor)
+                    self.logger.info(f'  | {anchor}')
 
     # -------------------------------------------------------------
 
@@ -368,8 +380,7 @@ class Generator(object):
                     tag.text = self._mixed_script
                     body.append(tag)
                 for src in scripts:
-                    body.append(soup.new_tag(
-                        'script', src='file://%s' % (src)))
+                    body.append(soup.new_tag('script', src=f'file://{src}'))
 
         return self._options.js_renderer.render(str(soup))
 
